Learn R Programming

intamap (version 1.3-36)

intamap: Example data for the intamap package

Description

Salted (slightly modified) observations from the European gamma radiation network

Usage

data(intamap)

Arguments

Details

The data set is a salted data set from the European gamma radiation network http://eurdep.jrc.ec.europa.eu/Basic/Pages/Public/Home/Default.aspx. Salted does in this context mean that all locations and observation values have been randomized through addition of a random value.