intamap: Example data for the intamap package
Description
Salted (slightly modified) observations from the European gamma radiation networkDetails
The data set is a salted data set from the European gamma radiation network
http://eurdep.jrc.ec.europa.eu/Basic/Pages/Public/Home/Default.aspx.
Salted does in this context mean that all locations and observation values
have been randomized through addition of a random value.